changeset 1819:df06a60f3362

* disass.el (disassemble): Add autoload cookie for this. * bytecomp.el (byte-decompile-bytecode): Add an autoload for this. compiled-function-p has been renamed to byte-code-function-p. * subr.el: Define compiled-function-p as an alias for it. * bytecomp.el: Register compiled-function-p as obsolete. * bytecomp.el, byte-opt.el, disass.el, help.el, map-ynp.el: Change uses. unread-command-event has been replaced by unread-command-events. * simple.el (prefix-arg-internal): Use this to push back all key sequences for processing by the main command loop, instead of trying to simulate its behavior ourselves. * bytecomp.el: Document unread-command-event as an obsolete variable, although nothing but the GNU Emacs 19 sources use it. Adjust obsolescence message for unread-command-char. * comint.el (comint-dynamic-list-completions): Change uses of unread-command-event to work with unread-command-events. * ebuff-menu.el (electric-buffer-list, Electric-buffer-menu-exit): Same. * edebug.el (edebug-outside-excursion): Same. * ehelp.el (electric-help-command-loop): Same. * electric.el (Electric-command-loop): Same. * emerge.el (emerge-show-file-name): Same. * fortran.el (fortran-abbrev-start, fortran-window-create-momentarily): Same. * gnus.el (gnus-Subject-next-article): Same. * info.el (Info-summary): Same. * isearch-mode.el (isearch-update, isearch-unread): Same. * map-ynp.el (map-y-or-n-p): Same. * mlsupport.el (push-back-character): Same. * replace.el (perform-replace): Same. * simula.el (simula-electric-label): Same. * subr.el (read-quoted-char, momentary-string-display): Same. * sun-mouse.el (mouse-second-hit): Same. * terminal.el (te-escape-extended-command-unread): Same. * vip.el (vip-escape-to-emacs, vip-prefix-arg-value, vip-prefix-arg-com): Same.
author Jim Blandy <jimb@redhat.com>
date Tue, 26 Jan 1993 01:36:02 +0000
parents 7e3322619e46
children b95bdb97c3e8
files lisp/emacs-lisp/bytecomp.el
diffstat 1 files changed, 18 insertions(+), 9 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/emacs-lisp/bytecomp.el	Tue Jan 26 01:29:51 1993 +0000
+++ b/lisp/emacs-lisp/bytecomp.el	Tue Jan 26 01:36:02 1993 +0000
@@ -177,8 +177,8 @@
 ;;       (defvar baud-rate (baud-rate))	;Define baud-rate if it's undefined
 ;; 
 ;;       (if (byte-compile-single-version)
 ;; 	  (defmacro compiled-function-p (x) "Emacs 18 doesn't have these." nil)
 ;; 	(defun compiled-function-p (x) "Emacs 18 doesn't have these." nil))
 ;; 
 ;;       (or (and (fboundp 'member)
 ;; 	       ;; avoid using someone else's possibly bogus definition of this.
@@ -215,6 +215,12 @@
 (autoload 'byte-optimize-lapcode "byte-opt")
 (autoload 'byte-compile-unfold-lambda "byte-opt")
 
+;; This is the entry point to the decompiler, which is used by the
+;; disassembler.  The disassembler just requires 'byte-compile, but
+;; that doesn't define this function, so this seems to be a reasonable
+;; thing to do.
+(autoload 'byte-decompile-bytecode "byte-opt")
+
 (defvar byte-compile-verbose
   (and (not noninteractive) (> baud-rate search-slow-speed))
   "*Non-nil means print messages describing progress of byte-compiler.")
@@ -837,9 +843,9 @@
 		      (or (symbolp (symbol-function fn))
 			  (consp (symbol-function fn))
 			  (and (not macro-p)
-			       (compiled-function-p (symbol-function fn)))))
+			       (byte-code-function-p (symbol-function fn)))))
 	    (setq fn (symbol-function fn)))
-	  (if (and (not macro-p) (compiled-function-p fn))
+	  (if (and (not macro-p) (byte-code-function-p fn))
 	      fn
 	    (and (consp fn)
 		 (if (eq 'macro (car fn))
@@ -1876,7 +1882,7 @@
 	     (if (memq 'callargs byte-compile-warnings)
 		 (byte-compile-callargs-warn form))
 	     (byte-compile-normal-call form))))
-	((and (or (compiled-function-p (car form))
+	((and (or (byte-code-function-p (car form))
 		  (eq (car-safe (car form)) 'lambda))
 	      ;; if the form comes out the same way it went in, that's
 	      ;; because it was malformed, and we couldn't unfold it.
@@ -2851,12 +2857,12 @@
 		 " <subr>")
 		((symbolp f)
 		 (format " ==> %s" f))
-		((compiled-function-p f)
+		((byte-code-function-p f)
 		 "<compiled function>")
 		((not (consp f))
 		 "<malformed function>")
 		((eq 'macro (car f))
-		 (if (or (compiled-function-p (cdr f))
+		 (if (or (byte-code-function-p (cdr f))
 			 (assq 'byte-code (cdr (cdr (cdr f)))))
 		     " <compiled macro>"
 		   " <macro>"))
@@ -2967,6 +2973,7 @@
 
 (make-obsolete 'buffer-flush-undo 'buffer-disable-undo)
 (make-obsolete 'baud-rate "use the baud-rate variable instead")
+(make-obsolete 'compiled-function-p 'byte-code-function-p)
 (make-obsolete-variable 'auto-fill-hook 'auto-fill-function)
 (make-obsolete-variable 'blink-paren-hook 'blink-paren-function)
 (make-obsolete-variable 'lisp-indent-hook 'lisp-indent-function)
@@ -2975,7 +2982,9 @@
 (make-obsolete-variable 'inhibit-local-variables
 		"use enable-local-variables (with the reversed sense.)")
 (make-obsolete-variable 'unread-command-char
-  "use unread-command-event; now nil means `no event', instead of -1.")
+  "use unread-command-events instead.  That variable is a list of events to reread, so it now uses nil to mean `no event', instead of -1.")
+(make-obsolete-variable 'unread-command-event
+  "use unread-command-events; this is now a list of events.")
 
 (provide 'byte-compile)
 
@@ -3012,7 +3021,7 @@
 ;; itself, compile some of its most used recursive functions (at load time).
 ;;
 (eval-when-compile
- (or (compiled-function-p (symbol-function 'byte-compile-form))
+ (or (byte-code-function-p (symbol-function 'byte-compile-form))
      (assq 'byte-code (symbol-function 'byte-compile-form))
      (let ((byte-optimize nil) ; do it fast
 	   (byte-compile-warnings nil))
@@ -177,8 +177,8 @@
 ;; 
 ;;       (if (byte-compile-single-version)
-;; 	  (defmacro compiled-function-p (x) "Emacs 18 doesn't have these." nil)
-;; 	(defun compiled-function-p (x) "Emacs 18 doesn't have these." nil))
+;; 	  (defmacro byte-code-function-p (x) "Emacs 18 doesn't have these." nil)
+;; 	(defun byte-code-function-p (x) "Emacs 18 doesn't have these." nil))
 ;; 
 ;;       (or (and (fboundp 'member)